@@ -36,7 +36,7 @@ rm tt
 # cat coord.txt | shuf | xargs -I {} -n 1 bash -c 'echo -e "samtools mpileup -DguS -f $1 -r {} -b bamlist.txt | bcftools view -bvcg - > tmpbcf/tmp.{}.bcf && bcftools view tmpbcf/tmp.{}.bcf > tmpbcf/tmp.{}.vcf\n"'
 
 #Getting rid of having a bcftools view on each chromosome - save it for the end
-cat coord.txt | shuf | xargs -I {} -n 1 bash -c "echo 'samtools mpileup -DguS -f $REF -r {} -b bamlist.txt | bcftools view -bvcg - > tmpbcf/tmp.{}.bcf'"
+cat coord.txt | shuf | xargs -I {} -n 1 bash -c "echo 'samtools mpileup -DguS -f $REF -r {} -b `pwd`/bamlist.txt | bcftools view -bvcg - > `pwd`/tmpbcf/tmp.{}.bcf'"
 
 #Wait for these to finish
 echo -e "wait\n" 
@@ -44,6 +44,6 @@ echo -e "wait\n"
 # Got to cat the bcf files back together
 # find `pwd`/tmpbcf | grep -e "bcf$" > bcflist.txt
 # Didn't work with the -f option not sure why
-echo "find `pwd`/tmpbcf/*bcf | xargs bcftools cat > merge.bcf && bcftools view merge.bcf > merge.vcf"
+echo "find `pwd`/tmpbcf/*bcf | xargs bcftools cat > `pwd`/merge.bcf && bcftools view `pwd`/merge.bcf > `pwd`/merge.vcf"
 
 rm coord.txt
